InsufficientData

Struct InsufficientData 

pub struct InsufficientData { /* private fields */ }
An error that occurs when trying to decode data from a buffer with insufficient data.

This error indicates that a decode operation failed because the buffer does not have enough remaining bytes to decode the value.

Implementations

Source

impl InsufficientData

pub const fn new(available: usize) -> InsufficientData

Creates a new InsufficientData error with only the available bytes.

pub const fn with_required( required: NonZero<usize>, available: usize, ) -> InsufficientData

Creates a new InsufficientData error with the required and available bytes.

Panics

Panics if required is not greater than available.

pub const fn required(&self) -> Option<NonZero<usize>>

Returns the number of bytes required to decode the value, if known.

pub const fn available(&self) -> usize

Returns the number of bytes available in the buffer.