pub struct TryReadError { /* private fields */ }Expand description
An error that occurs when trying to read data from a buffer with insufficient bytes.
This error indicates that a read operation failed because the buffer does not contain enough bytes to satisfy the request. Failed read operations do not consume any bytes - the buffer position remains unchanged.
Implementations
Sourceimpl TryReadError
impl TryReadError
Sourcepub const fn new(requested: NonZeroUsize, available: usize) -> Self
pub const fn new(requested: NonZeroUsize, available: usize) -> Self
Creates a new TryReadError with the requested and available bytes.
Panics
- If
requested <= available(this would not be an error condition). - The
requestedvalue must be a non-zero.
Sourcepub const fn requested(&self) -> NonZeroUsize
pub const fn requested(&self) -> NonZeroUsize
Returns the number of bytes requested for the operation.
This is the minimum number of bytes needed for the operation to succeed.